import {
  Component,
  OnInit,
  Input,
  Output,
  EventEmitter,
  AfterViewInit,
  ElementRef,
  Inject
} from '@angular/core';
import {
  TranslationEventJson,
  Info,
  MassTranslationEventJson
} from '@ucap-webmessenger/protocol-event';
import { UCAP_NATIVE_SERVICE, NativeService } from '@ucap-webmessenger/native';

@Component({
  selector: 'ucap-chat-message-box-mass-translation',
  templateUrl: './mass-translation.component.html',
  styleUrls: ['./mass-translation.component.scss']
})
export class MassTranslationComponent implements OnInit, AfterViewInit {
  @Input()
  message: Info<MassTranslationEventJson>;

  @Input()
  translationSimpleview: boolean;

  @Input()
  isMe: boolean;

  @Output()
  massTranslationDetail = new EventEmitter<{
    message: Info<MassTranslationEventJson>;
    contentsType: string;
  }>();

  @Output()
  contextMenu = new EventEmitter<{
    event: MouseEvent;
    type: string;
  }>();

  constructor(
    private elementRef: ElementRef,
    @Inject(UCAP_NATIVE_SERVICE) private nativeService: NativeService
  ) {}

  ngOnInit() {}

  ngAfterViewInit(): void {
    if (
      !!this.elementRef.nativeElement &&
      !!this.elementRef.nativeElement.querySelector('a')
    ) {
      const elements = this.elementRef.nativeElement.querySelectorAll('a');
      elements.forEach(element => {
        element.addEventListener('click', this.onClickEvent.bind(this));
      });
    }
  }

  onClickEvent(event: MouseEvent) {
    this.nativeService.openDefaultBrowser(
      (event.target as HTMLAnchorElement).text
    );
  }

  onClickMassDetail(contentsType: string) {
    this.massTranslationDetail.emit({
      message: this.message,
      contentsType
    });
  }

  onContextMenuMessage(event: MouseEvent, type: string) {
    this.contextMenu.emit({ event, type });
  }
}
